# -*- coding: utf-8 -*-
# Copyright (C) 2014-2024  EDF
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See https://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#
# Author : Konstantin Leontev (OpenCascade S.A.S)

import sys

from qtsalome import QGridLayout, QFrame, QApplication

from salome.geom.geomrepairadv.basedlg import BaseDlg
import GEOM

class LocateSubShapesDlg(BaseDlg):
    """
    Dialog for Locate Subshapes plugin that selects the sub-shapes of a compound
    by length, area or volume depending on whether it is an EDGE, a FACE or a SOLID.
    """
    def __init__(self, selection_level = GEOM.COMPOUND):
        # Implement widget's content here
        main_widget = QFrame()
        layout = QGridLayout(main_widget)
        layout.setContentsMargins(0, 0, 0, 0)

        BaseDlg.__init__(
            self, main_widget, 'Locate Subshapes', 'locate_subshapes_algo.py', False, selection_level)


# For testing run as a module from geomrepairadv parent directory in
# Salome INSTALL, because the dialog needs a generated Ui_BaseDlg class
# that we don't have in the SOURCE.
# Example:
# $ python -m geomrepairadv.locate_subshapes
if __name__ == '__main__':
    app = QApplication(sys.argv)

    dlg = LocateSubShapesDlg(None)
    dlg.show()

    sys.exit(app.exec_())
